/*
 * This software is governed by the CeCILL-B license under French law and
 * abiding by the rules of distribution of free software. You can use, modify
 * and/ or redistribute the software under the terms of the CeCILL-B license as
 * circulated by CEA, CNRS and INRIA at the following URL "http://www.cecill.info".
 * 
 * As a counterpart to the access to the source code and rights to copy, modify
 * and redistribute granted by the license, users are provided only with a
 * limited warranty and the software's author, the holder of the economic
 * rights, and the successive licensors have only limited liability.
 * 
 * In this respect, the user's attention is drawn to the risks associated with
 * loading, using, modifying and/or developing or reproducing the software by
 * the user in light of its specific status of free software, that may mean that
 * it is complicated to manipulate, and that also therefore means that it is
 * reserved for developers and experienced professionals having in-depth
 * computer knowledge. Users are therefore encouraged to load and test the
 * software's suitability as regards their requirements in conditions enabling
 * the security of their systems and/or data to be ensured and, more generally,
 * to use and operate it in the same conditions as regards security.
 * 
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL-B license and that you accept its terms.
 */

package fr.amap.commons.util.swing.jprogress;

import fr.amap.commons.util.swing.FrameView;

/**
 * Progression frame that can be used to display a loading of a process.
 * @author Tristan Muller (tristan.muller@cirad.fr)
 */
public class JProgressFrame extends FrameView {
    
    private javax.swing.JLabel jLabelStatus;
    private javax.swing.JPanel jPanelProgress;
    private javax.swing.JPanel jPanelStatus;
    private javax.swing.JProgressBar jProgressBar;
    private Runnable onInitCallback;

    public JProgressFrame() throws Exception {
        super();
        setLocationRelativeTo(getParent());
        setResizable(false);
        setVisible(true);
        
        if (onInitCallback != null) {
            onInitCallback.run();
        }
    }
    
    public void setOnInitCallback(final Runnable onInitCallback) {
        this.onInitCallback = onInitCallback;
    }
    
    public final void setProgression(final int current, final int max, final String message) {
        jProgressBar.setString(message);
        jProgressBar.setStringPainted(true);
        setProgression(current, max);
    }
    
    public final void setProgression(final int current, final int max) {
        jProgressBar.setMaximum(max);
        jProgressBar.setValue(current);
    }
    
    @Override
    protected void initContainer() throws Exception {
        setIconImage(loadIcon("/icons/progression.png").getImage());
        setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
        setTitle("Progression");
        getContentPane().setLayout(new javax.swing.BoxLayout(getContentPane(), 
                javax.swing.BoxLayout.PAGE_AXIS));
    }

    @Override
    protected void initComponents() throws Exception {
        jPanelProgress = new javax.swing.JPanel();
        jProgressBar = new javax.swing.JProgressBar();
        jPanelStatus = new javax.swing.JPanel();
        jLabelStatus = new javax.swing.JLabel();

        jProgressBar.setPreferredSize(new java.awt.Dimension(500, 19));
        jPanelProgress.add(jProgressBar);

        getContentPane().add(jPanelProgress);

        jLabelStatus.setText("Loading, please wait...");
        jPanelStatus.add(jLabelStatus);

        getContentPane().add(jPanelStatus);

        pack();
    }

}
